package com.jackyjjc.bookevaluator.controller;

import com.jackyjjc.bookevaluator.gui.WordDialog;
import com.jackyjjc.bookevaluator.model.Dictionary;
import com.jackyjjc.bookevaluator.model.WordList;

import java.awt.event.KeyEvent;
import java.util.Iterator;
import java.util.Set;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public class DictionaryUpdateListener extends WordDialogModifyListener {

    private Iterator<String> unknownWords;

    public DictionaryUpdateListener(Dictionary dict, Set<String> unknownWords) {
        super(dict, WordList.getWordList());
        this.unknownWords = unknownWords.iterator();
    }

    @Override
    public void keyReleased(KeyEvent e) {

        /*[esc] will dispose the dialog*/
        if(e.getKeyCode() == KeyEvent.VK_ESCAPE) {
            onClose();
            return;
        }

        //only [A], [S] and [W] will have effects
        if(e.getKeyCode() != KeyEvent.VK_A && e.getKeyCode() != KeyEvent.VK_S && e.getKeyCode() != KeyEvent.VK_W) {
            return;
        }

        //if [A] is pressed then the word is added into dictionary
        if(e.getKeyCode() == KeyEvent.VK_A) {
            dict.add(wordDialog.getWord());

        //press [W] to add the word to the word list
        } else if(e.getKeyCode() == KeyEvent.VK_W) {
            wordList.add(wordDialog.getWord());
        }
        //press [S] to just skip the word

        //display the next word
        if(unknownWords.hasNext()) {
            this.wordDialog.setWord(unknownWords.next());
        } else {
            this.onClose();
            this.wordDialog.dispose();
        }
    }

    @Override
    public void setWordDialog(WordDialog dialog) {
        this.wordDialog = dialog;
        this.wordDialog.setHelpMessage("[S] to skip the word",
                                       "[A] to add to dictionary",
                                       "[W] to add to word list");
    }
}
