package com.jackyjjc.bookevaluator.gui;

import com.jackyjjc.bookevaluator.controller.WordDialogListener;

import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public class WordDialog extends JFrame {

    private JLabel wordLabel;

    public WordDialog(final WordDialogListener listener) {

        super();

        //setting up the frame
        this.setLayout(new BoxLayout(this.getContentPane(), BoxLayout.Y_AXIS));
        this.setPreferredSize(new Dimension(500, 210));

        this.add(Box.createRigidArea(new Dimension(0, 40)));

        this.wordLabel = new JLabel();
        this.wordLabel.setFont(new Font("Arial", Font.BOLD, 20));
        this.wordLabel.setAlignmentX(Component.CENTER_ALIGNMENT);
        this.add(this.wordLabel);

        this.add(Box.createRigidArea(new Dimension(0, 20)));

        listener.setWordDialog(this);

        /*Intercept the closing behaviour*/
        setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent e) {
                super.windowClosing(e);
                listener.onClose();
                e.getWindow().dispose();
            }
        });
        //this dialog should listen to key presses to add words into dictionary
        addKeyListener(listener);

    }

    public void setWord(String word) {
        this.wordLabel.setText(word);
    }

    public String getWord() {
        return this.wordLabel.getText();
    }

    public void setHelpMessage(String... messages) {
        for(String msg : messages) {
            JLabel label = new JLabel(msg);
            label.setAlignmentX(Component.CENTER_ALIGNMENT);
            this.add(label);
        }
    }
}
