package com.jackyjjc.bookevaluator.io;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public class FileIO {

    public static void writeToFile(String path, Iterator<String> words) {
        try {
            File file = new File(path);

            java.io.FileWriter writer = new java.io.FileWriter(file, false);
            while (words.hasNext()) {
                writer.write(words.next() + "\n");
            }
            writer.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void appendToFile(String path, Iterator<String> words) {
        try {
            File file = new File(path);

            java.io.FileWriter writer = new java.io.FileWriter(file, true);
            while (words.hasNext()) {
                writer.append(words.next() + "\n");
            }
            writer.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static Set<String> readWordsFromInternalFile(String path) {

        Set<String> words = new HashSet<String>();

        try {
            File file = new File(path);

            if(!file.exists()) {
                file.createNewFile();
            }

            BufferedReader reader = new BufferedReader(new FileReader(file));

            String word;
            while((word = reader.readLine()) != null) {

                word = word.toLowerCase();

                if(!words.contains(word)) {
                    words.add(word);
                }
            }
        } catch (IOException e) {
            System.err.println("IOException in read words from internal file");
            System.exit(1);
        }

        return words;
    }

    public static String getPostfix(String path) {
        assert(path.contains("."));
        return path.substring(path.lastIndexOf("."));
    }

    public static boolean isValidPath(String path, String[] extension) {

        if(path == null) {
            return false;
        }

        File file = new File(path);

        if(!file.exists() || !file.canRead()) {
            return false;
        }

        String fileName = file.getName();
        boolean valid = false;

        for(int i = 0; i < extension.length && !valid; i++) {
            if(fileName.endsWith(extension[i])) {
                valid = true;
            }
        }

        return valid;
    }
}
