package com.jackyjjc.bookevaluator.main;

import com.jackyjjc.bookevaluator.io.FileIO;
import com.jackyjjc.bookevaluator.model.Dictionary;
import com.jackyjjc.bookevaluator.model.WordList;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public class BookEvaluator extends BookIterator {

    private static final String[] supportExtensions = new String[]{".txt"};

    private int unknownWordCount;
    private int numWords;

    public BookEvaluator() {
        super();
        this.unknownWordCount = 0;
    }

    public boolean setArguments(String... args) {

        if(args.length == 2 && FileIO.isValidPath(args[1], supportExtensions)) {
            return setPath(args[1]);
        }

        return false;
    }

    @Override
    public void onReadWord(Dictionary dictionary, WordList wordList, String word) {
        numWords++;
        if(!dictionary.contains(word)) {
            unknownWordCount++;
        }
    }

    @Override
    public void onFinish(Dictionary dictionary) {
        System.out.println("The number of unknown words is " + unknownWordCount + " out of " + numWords + ".");
        System.out.println("The unknown percentage is " + (((double)unknownWordCount) / numWords) * 100 + "%");
    }


}
