package com.jackyjjc.bookevaluator.main;

import com.jackyjjc.bookevaluator.io.BookReader;
import com.jackyjjc.bookevaluator.io.FileIO;
import com.jackyjjc.bookevaluator.io.TXTReader;
import com.jackyjjc.bookevaluator.model.Dictionary;
import com.jackyjjc.bookevaluator.model.WordList;

import java.io.File;
import java.io.IOException;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public abstract class BookIterator {

    private static final String[] supportExtensions = new String[]{".txt"};

    private String bookPath;

    public BookIterator() {
        this.bookPath = null;
    }

    public boolean setPath(String bookPath) {

        if(FileIO.isValidPath(bookPath, supportExtensions)) {
            this.bookPath = bookPath;
            return true;
        }

        return false;
    }

    public void run() {

        Dictionary dictionary = Dictionary.getDictionary();
        WordList wordList = WordList.getWordList();

        try {
            assert(this.bookPath != null);

            BookReader reader = getBookReader(this.bookPath);

            String word;
            while((word = reader.getNextWord()) != null) {
                onReadWord(dictionary, wordList, word);
            }

            reader.close();
        } catch (IOException e) {
            System.err.println("IO Error.");
            System.exit(1);
        }

        onFinish(dictionary);
    }

    private BookReader getBookReader(String bookPath) throws IOException {

        File bookFile = new File(bookPath);
        String postfix = FileIO.getPostfix(bookPath);
        BookReader reader = null;

        if(postfix.equals(".txt")) {
            reader = new TXTReader();
        }

        assert(reader != null);

        reader.open(bookFile);

        return reader;
    }

    public abstract void onReadWord(Dictionary dictionary, WordList wordList, String word);

    public abstract void onFinish(Dictionary dictionary);
}
