package com.jackyjjc.bookevaluator.main;

import com.jackyjjc.bookevaluator.controller.DictionaryUpdateListener;
import com.jackyjjc.bookevaluator.gui.WordDialog;
import com.jackyjjc.bookevaluator.model.Dictionary;
import com.jackyjjc.bookevaluator.model.WordList;

import java.util.HashSet;
import java.util.Set;

/**
 * @author Junjie CHEN(jacky.jjchen@gmail.com)
 */
public class DictionaryUpdater extends BookIterator {

    private boolean runThrough;
    private Set<String> unknownWords;

    public DictionaryUpdater() {
        super();
        this.runThrough = false;
        this.unknownWords = new HashSet<String>();
    }

    public boolean setArguments(String... args) {

        if(args.length == 2) {
            return setPath(args[1]);
        } else if(args.length == 3 && args[1].equals("-a")) {
            runThrough = true;
            return setPath(args[2]);
        }

        return false;
    }

    @Override
    public void onReadWord(Dictionary dictionary, WordList wordList, String word) {

        if(runThrough) {
            dictionary.add(word);
        } else {
            if(!dictionary.contains(word) && !wordList.contains(word)
                && !unknownWords.contains(word) && word.length() > 0) {
                unknownWords.add(word);
            }
        }
    }

    @Override
    public void onFinish(Dictionary dictionary) {

        if(runThrough) {
            dictionary.save();
        } else {
            WordDialog dialog = new WordDialog(new DictionaryUpdateListener(dictionary, unknownWords));
            dialog.pack();
            dialog.setVisible(true);
        }
    }
}
